==> veracity-source-1.0.0.10517.tar.gz: veracity/src/cmd/sg_prototypes.h <==
/*
Copyright 2010-2011 SourceGear, LLC

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

/**
 *
 * @file sg_prototypes.h
 *
 * @details
 *
 */

//////////////////////////////////////////////////////////////////

#ifndef H_SG_PROTOTYPES_H
#define H_SG_PROTOTYPES_H

BEGIN_EXTERN_C;

//////////////////////////////////////////////////////////////////

void sg_report_portability_warnings2(SG_context * pCtx, const SG_varray * pva);
void sg_report_portability_warnings(SG_context * pCtx, SG_pendingtree* pPendingTree);
void sg_report_action_log2(SG_context * pCtx, const SG_varray * pva);
void sg_report_action_log(SG_context * pCtx, SG_pendingtree* pPendingTree);
void sg_report_submodule_missing_details(SG_context * pCtx, const SG_varray * pvaMissingDetails);

//////////////////////////////////////////////////////////////////

void do_cmd_init_new_repo(SG_context * pCtx,
						  const char * pszRepoName,
						  const char * pszFolderName,
						  const char * pszStorage,
						  const char * pszHashMethod,
						  SG_bool bNoWd,
						  SG_bool bSubmodule,
                          const char * psz_shared_users);

void do_cmd_checkout(SG_context * pCtx,
	const char * pszRepoName,
	SG_rev_spec* pRevSpec,
	const char * pszFolder,
	const char* psz_attach,
	SG_bool bSubmodule,
	const SG_vector * pvec_use_submodules,
	int * pExitStatus);

void do_cmd_commit(SG_context * pCtx,
	SG_uint32 count_args, const char** paszArgs,
	const char* psz_comment,
	const char* psz_user,
	const char* psz_when,
	SG_stringarray* psa_stamps,
	SG_bool bRecursive,
	const SG_file_spec* pFilespec,
	const char* const* ppszAssocs, 
	SG_uint32 nCountAssocs,
    SG_bool bNoSubmodules,
    void (*promptfn)(SG_context *, SG_string *,char **,const SG_varray *),
	SG_string *boilerplate
);

void do_cmd_export(SG_context * pCtx,
	const char * pszRepoName,
	SG_rev_spec* pRevSpec,
	const char * pszFolder,
	SG_bool bNoSubmodules,
	const SG_vector * pvec_use_submodules);

void do_cmd_merge(SG_context * pCtx,
				  SG_rev_spec * pRevSpec,
				  const char * pszToolOverride,
				  SG_bool bVerbose,
				  SG_bool bTest,
				  const SG_vector * pvec_use_submodules);

void do_cmd_resolve(SG_context * pCtx,
					SG_option_state * pOptSt,
					SG_uint32 count_args,
					const char ** paszArgs);

void do_cmd_resolve2(SG_context * pCtx,
					SG_option_state * pOptSt,
					SG_uint32 count_args,
					const char ** paszArgs);

void do_cmd_update(SG_context * pCtx,
				   SG_rev_spec* pRevSpec,
				   const char * psz_attach,
				   SG_bool bVerbose,
				   SG_bool bTest,
				   const SG_vector * pvec_use_submodules,
				   int * pExitStatus);

void do_cmd_dump_lca(SG_context * pCtx,
					 SG_option_state * pOptSt);

void do_cmd_serve(SG_context * pCtx, 
				  SG_option_state* pOptSt,
				  int * pExitStatus);

//////////////////////////////////////////////////////////////////

END_EXTERN_C;

#endif//H_SG_PROTOTYPES_H

==> veracity-source-1.1.0.10565.tar.gz: veracity/src/cmd/sg_prototypes.h <==
/*
Copyright 2010-2011 SourceGear, LLC

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

/**
 *
 * @file sg_prototypes.h
 *
 * @details
 *
 */

//////////////////////////////////////////////////////////////////

#ifndef H_SG_PROTOTYPES_H
#define H_SG_PROTOTYPES_H

BEGIN_EXTERN_C;

//////////////////////////////////////////////////////////////////

void sg_report_portability_warnings2(SG_context * pCtx, const SG_varray * pva);
void sg_report_portability_warnings(SG_context * pCtx, SG_pendingtree* pPendingTree);
void sg_report_action_log2(SG_context * pCtx, const SG_varray * pva);
void sg_report_action_log(SG_context * pCtx, SG_pendingtree* pPendingTree);
void sg_report_submodule_missing_details(SG_context * pCtx, const SG_varray * pvaMissingDetails);

//////////////////////////////////////////////////////////////////

void do_cmd_init_new_repo(SG_context * pCtx,
						  const char * pszRepoName,
						  const char * pszFolderName,
						  const char * pszStorage,
						  const char * pszHashMethod,
						  SG_bool bNoWd,
						  SG_bool bSubmodule,
                          const char * psz_shared_users);

void do_cmd_checkout(SG_context * pCtx,
	const char * pszRepoName,
	SG_rev_spec* pRevSpec,
	const char * pszFolder,
	const char* psz_attach,
	SG_bool bSubmodule,
	const SG_vector * pvec_use_submodules,
	int * pExitStatus);

void do_cmd_commit(SG_context * pCtx,
	SG_uint32 count_args, const char** paszArgs,
	const char* psz_comment,
	const char* psz_user,
	const char* psz_when,
	SG_stringarray* psa_stamps,
	SG_bool bRecursive,
	const SG_file_spec* pFilespec,
	const char* const* ppszAssocs, 
	SG_uint32 nCountAssocs,
    SG_bool bNoSubmodules,
    void (*promptfn)(SG_context *, SG_string *,char **,const SG_varray *),
	SG_string *boilerplate
);

void do_cmd_fast_import(SG_context * pCtx,
    SG_option_state * pOptSt,
	const char * psz_fi,
	const char * psz_repo
	);

void do_cmd_fast_export(SG_context * pCtx,
    SG_option_state * pOptSt,
	const char * psz_repo,
	const char * psz_fi
	);

void do_cmd_export(SG_context * pCtx,
	const char * pszRepoName,
	SG_rev_spec* pRevSpec,
	const char * pszFolder,
	SG_bool bNoSubmodules,
	const SG_vector * pvec_use_submodules);

void do_cmd_merge(SG_context * pCtx,
				  SG_rev_spec * pRevSpec,
				  const char * pszToolOverride,
				  SG_bool bVerbose,
				  SG_bool bTest,
				  const SG_vector * pvec_use_submodules);

void do_cmd_resolve2(SG_context * pCtx,
					SG_option_state * pOptSt,
					SG_uint32 count_args,
					const char ** paszArgs);

void do_cmd_update(SG_context * pCtx,
				   SG_rev_spec* pRevSpec,
				   const char * psz_attach,
				   SG_bool bVerbose,
				   SG_bool bTest,
				   const SG_vector * pvec_use_submodules,
				   int * pExitStatus);

void do_cmd_dump_lca(SG_context * pCtx,
					 SG_option_state * pOptSt);

void do_cmd_serve(SG_context * pCtx, 
				  SG_option_state* pOptSt,
				  int * pExitStatus);

//////////////////////////////////////////////////////////////////

END_EXTERN_C;

#endif//H_SG_PROTOTYPES_H
